﻿angular.module('fwapp.controllers')

.controller('HealthController', function ($scope, $rootScope, $stateParams, $state, $timeout,
 $ionicPopover, $ionicModal, $ionicScrollDelegate, $ionicLoading, $ionicPlatform, $ionicPopup, $ionicActionSheet, $cordovaDatePicker, $cordovaInAppBrowser, $fwCordovaToast,
 AccountService, HealthService, VisitPatientService) {

    if ($stateParams.titleName != null && $stateParams.titleName.length > 0) {
        $scope.titleName = $stateParams.titleName;
    } else {
        $scope.titleName = "健康记录";
    }
    $scope.tabName = "记录";
    //血压记录
    $scope.bp = {
        newSBP: "",
        newDBP: "",
        modifySBP: "",
        modifyDBP: "",
        bpid: "",
        measureTime: ""
    };
    //心率记录
    $scope.hr = {
        newRate: "",
        modifyRate: "",
        hrid: "",
        measureTime: ""
    };
    //特殊事件
    $scope.se = {
        symptoms: "",
        appearedTime: "",
        seid: "",
        durationHour: "",
        durationMinute: "",
        relieveMethod: ""
    }
    // 身高体重
    $scope.hw = {
        newHeight: "",
        newWeight: "",
        modifyHeight: "",
        modifyWeight: "",
        htid: "",
        measureTime: ""
    };
    // 血糖
    $scope.bg = {
        newGlu: "",
        modifyGlu: "",
        bgid: "",
        measureTime: "",
        timeArea: ""
    };
    //血压记录列表
    $scope.BloodPressureList = new Object();
    //心率记录列表
    $scope.HeartRateList = new Object();
    //特殊事件列表
    $scope.SpecialEventList = new Object();
    // 身高体重列表
    $scope.HeightWeightList = new Object();
    // 血糖列表
    $scope.BloodGlucoseList = new Object();

    // 检查登录状态
    $rootScope.checkLogin();
    // 打哪来
    $scope.from = ($stateParams.vpid == null || $stateParams.vpid.length == 0) ? "menu" : "vpInfo";
    if ($stateParams.from != null && $stateParams.from.length != 0) {
        $scope.from = $stateParams.from;
    }
    // 就诊人ID
    $scope.vpId = ($stateParams.vpid == null || $stateParams.vpid.length == 0) ? "" : $stateParams.vpid;
    // 就诊人信息
    $scope.vpInfo = new Object();
    // 用户信息
    $scope.accountInfo = new Object();

    $scope.vpList = new Object();
    //标题
    $scope.titleList = [
        { name: '血压' },
        { name: '心率' },
        { name: '特殊事件' },
        { name: '身高体重' },
        { name: '血糖' }
    ]

    $scope.chartType = {
        bp: "byDay",
        hr: "byDay",
        hw: "byDay",
        bg: "byDay"
    }

    // 建议list
    $scope.hlthAdviceList = [];

    // 心脑血管病风险评估 开关
    $scope.cvdRiskServerStatus = devMode ? true : false;

    // 注册弹出菜单：就诊人列表
    $ionicPopover.fromTemplateUrl('pop_vplist.html', {
        scope: $scope
    }).then(function (popover) {
        $scope.popVplist = popover;
    });

    // 注册弹出菜单：标题列表
    $ionicPopover.fromTemplateUrl('title_popover.html', {
        scope: $scope
    }).then(function (popover) {
        $scope.titlePopver = popover;
    });

    // 初始化
    $scope.$on('$ionicView.loaded', function () {
        if (!$rootScope.checkLogin()) {
            return;
        }
        $scope.vpList = [];
        // 获取就诊人列表
        VisitPatientService.visitPatientList().then(function (data) {
            // 获取成功
            if (data.result == 1) {
                // 若无就诊人
                if (data.data.length == 0) {
                    $state.go("app.personal");
                    $fwCordovaToast.showShortBottom("未找到绑定的就诊人信息");
                    return;
                }

                // 第一就诊人
                var vpid = "";
                for (var i = 0; i < data.data.length; i++) {
                    $scope.vpList.push(data.data[i]);
                    if (vpid == "") {
                        vpid = data.data[i].VISIT_PATIENT_ID;
                    }
                }

                // 若参数无就诊人信息
                if ($scope.vpId == "") {
                    // 默认第一就诊人
                    $scope.vpId = vpid;
                }
            }
            // 获取失败
            else {
                $fwCordovaToast.showShortBottom(data.msg);
            }

            // 读取就诊人信息
            $scope.loadVpInfo();
            // 读取就诊人列表
            $scope.loadVpList();

            // 获取用户信息
            AccountService.accountInfo().then(function (data) {
                if (data.result == 1) {
                    $scope.accountInfo = data.data;
                } else {
                    $fwCordovaToast.showShortBottom(data.msg);
                }
            })

            $scope.loadBloodPressureList();

            $scope.loadHeartRateList();

            $scope.loadSpecialEventList();

            // 2021-3-12 13:25:19 HM 应4S标准，增加健康指标
            $scope.getHlthAdvice();
        })
    });

    $scope.loadBloodPressureList = function () {
        HealthService.getBloodPressureList($scope.vpId).then(function (data) {
            $scope.BloodPressureList = data.ds;
            //console.log(data.ds);
        });
    }

    $scope.loadHeartRateList = function () {
        //$fwCordovaToast.showShortBottom("loadHeartRateList");
        HealthService.getHeartRateList($scope.vpId).then(function (data) {
            $scope.HeartRateList = data.ds;
            //console.log(data.ds);
            //$fwCordovaToast.showShortBottom(data.ds);
        });
    }

    $scope.loadSpecialEventList = function () {
        HealthService.getSpecialEventList($scope.vpId).then(function (data) {
            $scope.SpecialEventList = data.ds;
            //console.log(data.ds);
        });
    }

    // 获取身高体重记录
    $scope.loadHeightWeightList = function () {
        HealthService.getHeightWeightList($scope.vpId).then(function (data) {
            $scope.HeightWeightList = data.ds;
            console.log($scope.HeightWeightList);

            $ionicScrollDelegate.resize();
            $ionicScrollDelegate.scrollTop();
        });
    }

    // 获取血糖记录
    $scope.loadBloodGlucoseList = function () {
        HealthService.getBloodGlucoseList($scope.vpId).then(function (data) {
            $scope.BloodGlucoseList = data.ds;
            console.log($scope.BloodGlucoseList);

            $ionicScrollDelegate.resize();
            $ionicScrollDelegate.scrollTop();
        });
    }

    //读取就诊人信息
    $scope.loadVpInfo = function () {
        VisitPatientService.visitPatientInfo($scope.vpId).then(function (data) {
            if (data.result == 0) {
                $fwCordovaToast.showShortBottom(data.msg);
            } else {
                $scope.vpInfo = data.data;
            }
        })
    }

    // 加载就诊人列表
    $scope.loadVpList = function () {
        // 就诊人列表
        VisitPatientService.visitPatientList().then(function (data) {
            // 获取成功
            if (data.result == 1) {
                $scope.vpList = data.data;
                //console.log(data);
            }
            // 获取失败
            else {
                $fwCordovaToast.showShortBottom(data.msg);
            }
        })
    }

    // 切换就诊人
    $scope.changeVp = function (vpid) {
        $scope.vpId = vpid
        $scope.vpInfo = new Object();
        $scope.loadVpInfo();
        $scope.popVplist.hide();
        $scope.getHlthAdvice();

        if ($scope.titleName == "血压") {
            $scope.loadBloodPressureList();
            if ($scope.tabName == '趋势') {
                chartBloodPressure();
            }
        } else if ($scope.titleName == "心率") {
            $scope.loadHeartRateList();
            if ($scope.tabName == '趋势') {
                chartHeartRate();
            }
        } else if ($scope.titleName == "特殊事件") {
            $scope.loadSpecialEventList();
        } else if ($scope.titleName == "身高体重") {
            $scope.loadHeightWeightList();
            if ($scope.tabName == '趋势') {
                chartHeightWeight();
            }
        } else if ($scope.titleName == "血糖") {
            $scope.loadBloodGlucoseList();
            if ($scope.tabName == '趋势') {
                chartBloodGlucose();
            }
        } else {
            $scope.loadBloodPressureList();
            $scope.loadHeartRateList();
            $scope.loadSpecialEventList();
            chartHeartRate();
            chartBloodPressure();
        }
    }

    // 切换标题/类型
    $scope.changeTitle = function (titleName) {
        $scope.titleName = titleName;
        $scope.titlePopver.hide();

        $scope.changeVp($scope.vpId);
    }

    // 显示弹出菜单
    $scope.openPopoverVpList = function ($event) {
        $scope.popVplist.show($event);
    }

    // 显示弹出菜单
    $scope.openTitlePopover = function ($event) {
        $scope.titlePopver.show($event);
    }

    //血压
    //添加血压modal
    $ionicModal.fromTemplateUrl('add-blood-pressure.html', {
        scope: $scope,
        animation: 'slide-in-up'
    }).then(function (modal) {
        $scope.addBloodPressureModal = modal;
    });
    //打开添加血压modal
    $scope.openAddBloodPressureModal = function () {
        $scope.bp.newSBP = "";
        $scope.bp.newDBP = "";
        $scope.addBloodPressureModal.show();
        //var dtNow = new Date();
        //var dtNowString = dtNow.getFullYear() + "-" + (dtNow.getMonth() + 1) + "-" + dtNow.getDate() + " " + dtNow.getHours() + ":" + dtNow.getMinutes()
        $scope.bp.measureTime = "";
    }
    //关闭添加血压modal
    $scope.closeAddBloodPressureModal = function () {
        $scope.addBloodPressureModal.hide();
    }
    //添加血压记录
    $scope.AddBloodPressure = function () {
        //console.log("newSBP:" + $scope.bp.newSBP + "    newDBP:" + $scope.bp.newDBP);
        if ($scope.bp.newSBP == "" || $scope.bp.newDBP == "" || $scope.bp.newSBP == null || $scope.bp.newDBP == null) {
            $fwCordovaToast.showShortBottom("请填写高压和低压");
        } else if ($scope.bp.measureTime == "") {
            $fwCordovaToast.showShortBottom("请填写记录时间");
        } else {
            HealthService.addBloodPressure($scope.vpId, $scope.bp.newSBP, $scope.bp.newDBP, $scope.bp.measureTime).then(function (data) {
                if (data.code == 1) {
                    $scope.addBloodPressureModal.hide();
                    $scope.loadBloodPressureList();
                } else if (data.code == 0) {

                }

                $fwCordovaToast.showShortBottom(data.msg);
            });
        }
    }

    //修改血压modal
    $ionicModal.fromTemplateUrl('modify-blood-pressure.html', {
        scope: $scope,
        animation: 'slide-in-up'
    }).then(function (modal) {
        $scope.modifyBloodPressureModal = modal;
    });
    //打开修改血压modal
    $scope.openModifyBloodPressureModal = function (bpid, sbp, dbp, measureTime) {
        $scope.modifyBloodPressureModal.show();
        $scope.bp.bpid = bpid;
        $scope.bp.modifySBP = parseInt(sbp);
        $scope.bp.modifyDBP = parseInt(dbp);
        $scope.bp.measureTime = measureTime;
    }
    //关闭修改血压modal
    $scope.closeModifyBloodPressureModal = function () {
        $scope.modifyBloodPressureModal.hide();
    }
    //修改血压记录
    $scope.ModifyBloodPressure = function () {
        if ($scope.bp.modifySBP == "" || $scope.bp.modifyDBP == "" || $scope.bp.modifySBP == null || $scope.bp.modifyDBP == null) {
            $fwCordovaToast.showShortBottom("请填写高压和低压");
        } else if ($scope.bp.measureTime == "") {
            $fwCordovaToast.showShortBottom("请填写记录时间");
        } else {
            HealthService.modifyBloodPressure($scope.bp.bpid, $scope.bp.modifySBP, $scope.bp.modifyDBP, $scope.bp.measureTime).then(function (data) {
                if (data.code == 1) {
                    $scope.modifyBloodPressureModal.hide();
                    $scope.loadBloodPressureList();
                } else if (data.code == 0) {

                }

                $fwCordovaToast.showShortBottom(data.msg);
            });
        }
    }
    //删除血压记录
    $scope.DeleteBloodPressure = function () {
        var confirmBpPopup = $ionicPopup.confirm({
            title: '确认删除',
            template: '是否确认删除本条血压记录',
            cancelText: '取消',
            okText: '删除'
        });

        confirmBpPopup.then(function (res) {
            if (res) {
                HealthService.deleteBloodPressure($scope.bp.bpid, 0).then(function (data) {
                    if (data.code == 1) {
                        $scope.modifyBloodPressureModal.hide();
                        $scope.loadBloodPressureList();
                    } else if (data.code == 0) {

                    }

                    $fwCordovaToast.showShortBottom(data.msg);
                });
            }
            else {

            }
        });
    }
    //长按出菜单删除
    $scope.onHoldBp = function (bpid) {
        var ActionSheetBp = $ionicActionSheet.show({
            destructiveText: '删除',
            cancelText: '取消',
            destructiveButtonClicked: function () {
                ActionSheetBp();

                var confirmBpPopup = $ionicPopup.confirm({
                    title: '确认删除',
                    template: '是否确认删除本条血压记录',
                    cancelText: '取消',
                    okText: '删除'
                });

                confirmBpPopup.then(function (res) {
                    if (res) {
                        HealthService.deleteBloodPressure(bpid, '-1').then(function (data) {
                            if (data.code == 1) {
                                $scope.modifyBloodPressureModal.hide();
                                $scope.loadBloodPressureList();
                            } else if (data.code == 0) {

                            }

                            $fwCordovaToast.showShortBottom(data.msg);
                        });
                    }
                    else {

                    }
                });
            }
        });
    }

    //心率
    //添加心率modal
    $ionicModal.fromTemplateUrl('add-heart-rate.html', {
        scope: $scope,
        animation: 'slide-in-up'
    }).then(function (modal) {
        $scope.addHeartRateModal = modal;
    });
    //打开添加心率modal
    $scope.openAddHeartRateModal = function () {
        $scope.hr.newRate = "";
        $scope.addHeartRateModal.show();
        //var dtNow = new Date();
        //var dtNowString = dtNow.getFullYear() + "-" + (dtNow.getMonth() + 1) + "-" + dtNow.getDate() + " " + dtNow.getHours() + ":" + dtNow.getMinutes()
        $scope.hr.measureTime = "";
    }
    //关闭添加心率modal
    $scope.closeAddHeartRateModal = function () {
        $scope.addHeartRateModal.hide();
    }
    //添加心率记录
    $scope.AddHeartRate = function () {
        if ($scope.hr.newRate == "" || $scope.hr.newRate == null) {
            $fwCordovaToast.showShortBottom("请填写心率");
        } else if ($scope.hr.measureTime == "" || $scope.hr.measureTime == null) {
            $fwCordovaToast.showShortBottom("请填写记录时间");
        } else {
            HealthService.addHeartRate($scope.vpId, $scope.hr.newRate, $scope.hr.measureTime).then(function (data) {
                if (data.code == 1) {
                    $scope.addHeartRateModal.hide();
                    $scope.loadHeartRateList();
                } else if (data.code == 0) {

                }

                $fwCordovaToast.showShortBottom(data.msg);
            });
        }
    }

    //修改心率modal
    $ionicModal.fromTemplateUrl('modify-heart-rate.html', {
        scope: $scope,
        animation: 'slide-in-up'
    }).then(function (modal) {
        $scope.modifyHeartRateModal = modal;
    });
    //打开修改心率modal
    $scope.openModifyHeartRateModal = function (hrid, rate, measureTime) {
        $scope.modifyHeartRateModal.show();
        $scope.hr.hrid = hrid;
        $scope.hr.modifyRate = parseInt(rate);
        $scope.hr.measureTime = measureTime;
    }
    //关闭修改心率modal
    $scope.closeModifyHeartRateModal = function () {
        $scope.modifyHeartRateModal.hide();
    }
    //修改心率记录
    $scope.ModifyHeartRate = function () {
        if ($scope.hr.modifyRate == "" || $scope.hr.modifyRate == null) {
            $fwCordovaToast.showShortBottom("请填写心率");
        } else if ($scope.hr.measureTime == "" || $scope.hr.measureTime == null) {
            $fwCordovaToast.showShortBottom("请填写记录时间");
        } else {
            HealthService.modifyHeartRate($scope.hr.hrid, $scope.hr.modifyRate, $scope.hr.measureTime).then(function (data) {
                if (data.code == 1) {
                    $scope.modifyHeartRateModal.hide();
                    $scope.loadHeartRateList();
                } else if (data.code == 0) {

                }

                $fwCordovaToast.showShortBottom(data.msg);
            });
        }
    }
    //删除心率记录
    $scope.DeleteHeartRate = function () {
        var confirmHrPopup = $ionicPopup.confirm({
            title: '确认删除',
            template: '是否确认删除本条心率记录',
            cancelText: '取消',
            okText: '删除'
        });

        confirmHrPopup.then(function (res) {
            if (res) {
                HealthService.deleteHeartRate($scope.hr.hrid, 0).then(function (data) {
                    if (data.code == 1) {
                        $scope.modifyHeartRateModal.hide();
                        $scope.loadHeartRateList();
                    } else if (data.code == 0) {

                    }

                    $fwCordovaToast.showShortBottom(data.msg);
                });
            } else {

            }
        });
    }
    //长按出菜单删除
    $scope.onHoldHr = function (hrid) {
        var ActionSheetHr = $ionicActionSheet.show({
            destructiveText: '删除',
            cancelText: '取消',
            destructiveButtonClicked: function () {
                ActionSheetHr();

                var confirmHrPopup = $ionicPopup.confirm({
                    title: '确认删除',
                    template: '是否确认删除本条心率记录',
                    cancelText: '取消',
                    okText: '删除'
                });

                confirmHrPopup.then(function (res) {
                    if (res) {
                        HealthService.deleteHeartRate(hrid, '-1').then(function (data) {
                            if (data.code == 1) {
                                $scope.modifyHeartRateModal.hide();
                                $scope.loadHeartRateList();
                            } else if (data.code == 0) {

                            }

                            $fwCordovaToast.showShortBottom(data.msg);
                        });
                    } else {

                    }
                });
            }
        });
    }

    //特殊事件
    //添加特殊事件modal
    $ionicModal.fromTemplateUrl('add-special-event.html', {
        scope: $scope,
        animation: 'slide-in-up'
    }).then(function (modal) {
        $scope.addSpecialEventModal = modal;
    });
    //打开添加特殊事件modal
    $scope.openAddSpecialEventModal = function () {
        $scope.se.symptoms = "";
        $scope.se.appearedTime = "";
        $scope.se.seid = "";
        $scope.se.durationHour = "";
        $scope.se.durationMinute = "";
        $scope.se.relieveMethod = "";

        $scope.addSpecialEventModal.show();
        //var dtNow = new Date();
        //var dtNowString = dtNow.getFullYear() + "-" + (dtNow.getMonth() + 1) + "-" + dtNow.getDate() + " " + dtNow.getHours() + ":" + dtNow.getMinutes()
        //$scope.se.appearedTime = dtNowString;
    }
    //关闭添加特殊事件modal
    $scope.closeAddSpecialEventModal = function () {
        $scope.addSpecialEventModal.hide();
    }
    //添加特殊事件记录
    $scope.AddSpecialEvent = function () {
        if ($scope.se.symptoms == "" || $scope.se.symptoms == null) {
            $fwCordovaToast.showShortBottom("请填写症状");
        } else if ($scope.se.appearedTime == "" || $scope.se.appearedTime == null) {
            $fwCordovaToast.showShortBottom("请填写记录时间");
        } else {
            //console.log($scope.se.durationHour.length);
            //console.log($scope.se.durationMinute.length);
            //if ($scope.se.durationHour.length <= 0) {
            //    $fwCordovaToast.showShortBottom("请填写小时数");
            //} else if ($scope.se.durationMinute.length <= 0) {
            //    $fwCordovaToast.showShortBottom("请填写分钟数");
            //} else {

            try {
                if (parseInt($scope.se.durationMinute) <= 60 && parseInt($scope.se.durationMinute) >= 0) {
                    HealthService.addSpecialEvent($scope.vpId, $scope.se.symptoms, $scope.se.durationHour, $scope.se.durationMinute, $scope.se.relieveMethod, $scope.se.appearedTime).then(function (data) {
                        if (data.code == 1) {
                            $scope.addSpecialEventModal.hide();
                            $scope.loadSpecialEventList();
                        } else if (data.code == 0) {

                        }

                        $fwCordovaToast.showShortBottom(data.msg);
                    });
                } else {
                    $fwCordovaToast.showShortBottom("分钟数必须为0-60之间的整数");
                }
            } catch (err) {
                console.log(err);
                $fwCordovaToast.showShortBottom("请填写小时数和分钟数");
            }
            //}
        }
    }

    //修改特殊事件modal
    $ionicModal.fromTemplateUrl('modify-special-event.html', {
        scope: $scope,
        animation: 'slide-in-up'
    }).then(function (modal) {
        $scope.modifySpecialEventModal = modal;
    });
    //打开修改特殊事件modal
    $scope.openModifySpecialEventModal = function (seid, symptoms, appearedTime, durationHour, durationMinute, relieveMethod) {
        $scope.modifySpecialEventModal.show();
        $scope.se.seid = seid;
        $scope.se.symptoms = symptoms;
        $scope.se.appearedTime = appearedTime;
        $scope.se.durationHour = parseInt(durationHour);
        $scope.se.durationMinute = parseInt(durationMinute);
        $scope.se.relieveMethod = relieveMethod;
    }
    //关闭修改特殊事件modal
    $scope.closeSpecialEventModal = function () {
        $scope.modifySpecialEventModal.hide();
    }
    //修改特殊事件记录
    $scope.ModifySpecialEvent = function () {
        if ($scope.se.symptoms == "" || $scope.se.symptoms == null) {
            $fwCordovaToast.showShortBottom("请填写症状");
        } else if ($scope.se.appearedTime == "" || $scope.se.appearedTime == null) {
            $fwCordovaToast.showShortBottom("请填写记录时间");
        } else {
            //if ($scope.se.durationHour.length <= 0) {
            //    $fwCordovaToast.showShortBottom("请填写小时数");
            //} else if ($scope.se.durationMinute.length <= 0) {
            //    $fwCordovaToast.showShortBottom("请填写分钟数");
            //} else {
            try {
                if (parseInt($scope.se.durationMinute) <= 60 && parseInt($scope.se.durationMinute) >= 0) {
                    HealthService.modifySpecialEvent($scope.se.seid, $scope.se.symptoms, $scope.se.durationHour, $scope.se.durationMinute, $scope.se.relieveMethod, $scope.se.appearedTime).then(function (data) {
                        if (data.code == 1) {
                            $scope.modifySpecialEventModal.hide();
                            $scope.loadSpecialEventList();
                        } else if (data.code == 0) {

                        }

                        $fwCordovaToast.showShortBottom(data.msg);
                    });
                } else {
                    $fwCordovaToast.showShortBottom("分钟数必须为0-60之间的整数");
                }
            } catch (err) {
                console.log(err);
                $fwCordovaToast.showShortBottom("请填写小时数和分钟数");
            }
            //}
        }
    }
    //删除特殊事件记录
    $scope.DeleteSpecialEvent = function () {
        var confirmSePopup = $ionicPopup.confirm({
            title: '确认删除',
            template: '是否确认删除本条特殊事件记录',
            cancelText: '取消',
            okText: '删除'
        });

        confirmSePopup.then(function (res) {
            if (res) {
                HealthService.deleteSpecialEvent($scope.se.seid, 0).then(function (data) {
                    if (data.code == 1) {
                        $scope.modifySpecialEventModal.hide();
                        $scope.loadSpecialEventList();
                    } else if (data.code == 0) {

                    }

                    $fwCordovaToast.showShortBottom(data.msg);
                });
            } else {

            }
        });
    }
    //长按出菜单删除
    $scope.onHoldSe = function (seid) {
        var ActionSheetSe = $ionicActionSheet.show({
            destructiveText: '删除',
            cancelText: '取消',
            destructiveButtonClicked: function () {
                ActionSheetSe();

                var confirmSePopup = $ionicPopup.confirm({
                    title: '确认删除',
                    template: '是否确认删除本条特殊事件记录',
                    cancelText: '取消',
                    okText: '删除'
                });

                confirmSePopup.then(function (res) {
                    if (res) {
                        HealthService.deleteSpecialEvent(seid, '-1').then(function (data) {
                            if (data.code == 1) {
                                $scope.modifySpecialEventModal.hide();
                                $scope.loadSpecialEventList();
                            } else if (data.code == 0) {

                            }

                            $fwCordovaToast.showShortBottom(data.msg);
                        });
                    } else {

                    }
                });
            }
        });
    }

    // #region 身高体重
    //添加身高体重modal
    $ionicModal.fromTemplateUrl('add-height-weight.html', {
        scope: $scope,
        animation: 'slide-in-up'
    }).then(function (modal) {
        $scope.addHeightWeightModal = modal;
    });
    //打开添加身高体重modal
    $scope.openAddHeightWeightModal = function () {
        $scope.hw.newHeight = "";
        $scope.hw.newWeight = "";
        $scope.addHeightWeightModal.show();
        $scope.hw.measureTime = "";
    }
    //关闭添加身高体重modal
    $scope.closeAddHeightWeightModal = function () {
        $scope.addHeightWeightModal.hide();
    }
    //添加身高体重记录
    $scope.AddHeightWeight = function () {
        if ($scope.hw.newHeight == "" || $scope.hw.newWeight == "" || $scope.hw.newHeight == null || $scope.hw.newWeight == null) {
            $fwCordovaToast.showShortBottom("请填写身高和体重");
        } else if ($scope.hw.measureTime == "") {
            $fwCordovaToast.showShortBottom("请填写记录时间");
        } else {
            HealthService.submitHeightWeight($scope.vpId, $scope.hw.newHeight, $scope.hw.newWeight, "Health", $scope.hw.measureTime).then(function (data) {
                if (data.result == 1) {
                    $scope.addHeightWeightModal.hide();
                    $scope.loadHeightWeightList();

                    $fwCordovaToast.showShortBottom("添加身高体重记录成功");
                } else {
                    $fwCordovaToast.showShortBottom(data.msg);
                }
            });
        }
    }

    //修改身高体重model
    $ionicModal.fromTemplateUrl('modify-height-weight.html', {
        scope: $scope,
        animation: 'slide-in-up'
    }).then(function (modal) {
        $scope.modifyHeightWeightModal = modal;
    });
    //打开修改身高体重modal
    $scope.openModifyHeightWeightModal = function (htid, height, weight, measureTime) {
        $scope.modifyHeightWeightModal.show();
        $scope.hw.htid = htid;
        $scope.hw.modifyHeight = parseInt(height);
        $scope.hw.modifyWeight = parseInt(weight);
        $scope.hw.measureTime = measureTime;
    }
    //关闭修改身高体重modal
    $scope.closeModifyHeightWeightModal = function () {
        $scope.modifyHeightWeightModal.hide();
    }
    //修改身高体重
    $scope.ModifyHeightWeight = function () {
        if ($scope.hw.modifyHeight == "" || $scope.hw.modifyWeight == "" || $scope.hw.modifyHeight == null || $scope.hw.modifyWeight == null) {
            $fwCordovaToast.showShortBottom("请填写身高和体重");
        } else if ($scope.hw.measureTime == "") {
            $fwCordovaToast.showShortBottom("请填写记录时间");
        } else {
            HealthService.modifyHeigthWeight($scope.hw.htid, $scope.hw.modifyHeight, $scope.hw.modifyWeight, $scope.hw.measureTime).then(function (data) {
                if (data.result == 1) {
                    $scope.modifyHeightWeightModal.hide();
                    $scope.loadHeightWeightList();

                    $fwCordovaToast.showShortBottom("修改身高体重记录成功");
                } else {

                    $fwCordovaToast.showShortBottom(data.msg);
                }
            });
        }
    }
    //删除身高体重记录
    $scope.DeleteHeightWeight = function () {
        var confirmBpPopup = $ionicPopup.confirm({
            title: '确认删除',
            template: '是否确认删除本条身高体重记录',
            cancelText: '取消',
            okText: '删除'
        });

        confirmBpPopup.then(function (res) {
            if (res) {
                HealthService.deleteHeightWeight($scope.hw.htid).then(function (data) {
                    if (data.result == 1) {
                        $scope.modifyHeightWeightModal.hide();
                        $scope.loadHeightWeightList();

                        $fwCordovaToast.showShortBottom("删除成功");
                    } else {
                        $fwCordovaToast.showShortBottom(data.msg);
                    }
                });
            }
            else {

            }
        });
    }
    //长按出菜单删除
    $scope.onHoldHt = function (htid) {
        var ActionSheetHt = $ionicActionSheet.show({
            destructiveText: '删除',
            cancelText: '取消',
            destructiveButtonClicked: function () {
                ActionSheetHt();

                var confirmBpPopup = $ionicPopup.confirm({
                    title: '确认删除',
                    template: '是否确认删除本条身高体重记录',
                    cancelText: '取消',
                    okText: '删除'
                });

                confirmBpPopup.then(function (res) {
                    if (res) {
                        HealthService.deleteHeightWeight(htid).then(function (data) {
                            if (data.result == 1) {
                                $scope.loadHeightWeightList();

                                $fwCordovaToast.showShortBottom("删除成功");
                            } else {
                                $fwCordovaToast.showShortBottom(data.msg);
                            }
                        });
                    }
                    else {

                    }
                });
            }
        });
    }

    // #endregion

    // #region 血糖
    //添加血糖modal
    $ionicModal.fromTemplateUrl('add-blood-glucose.html', {
        scope: $scope,
        animation: 'slide-in-up'
    }).then(function (modal) {
        $scope.addBloodGlucoseModal = modal;
    });
    //打开添加血糖modal
    $scope.openAddBloodGlucoseModal = function () {
        $scope.bg.newGlu = "";
        $scope.addBloodGlucoseModal.show();
        //var dtNow = new Date();
        //var dtNowString = dtNow.getFullYear() + "-" + (dtNow.getMonth() + 1) + "-" + dtNow.getDate() + " " + dtNow.getHours() + ":" + dtNow.getMinutes()
        $scope.bg.measureTime = "";
    }
    //关闭添加血糖modal
    $scope.closeAddBloodGlucoseModal = function () {
        $scope.addBloodGlucoseModal.hide();
    }
    //添加血糖记录
    $scope.AddBloodGlucose = function () {
        if ($scope.bg.newGlu == "" || $scope.bg.newGlu == null) {
            $fwCordovaToast.showShortBottom("请填写血糖值");
        } else if ($scope.bg.measureTime == "") {
            $fwCordovaToast.showShortBottom("请填写记录时间");
        } else if ($scope.bg.timeArea == "") {
            $fwCordovaToast.showShortBottom("请选择时间段");
        }
        else {
            HealthService.addBloodGlucose($scope.vpId, $scope.bg.newGlu, $scope.bg.measureTime, $scope.bg.timeArea).then(function (data) {
                if (data.result == 1) {
                    $scope.addBloodGlucoseModal.hide();
                    $scope.loadBloodGlucoseList();

                    $fwCordovaToast.showShortBottom("添加成功");
                } else {
                    $fwCordovaToast.showShortBottom(data.msg);
                }

            });
        }
    }

    //修改血糖modal
    $ionicModal.fromTemplateUrl('modify-blood-glucose.html', {
        scope: $scope,
        animation: 'slide-in-up'
    }).then(function (modal) {
        $scope.modifyBloodGlucoseModal = modal;
    });
    //打开修改血糖modal
    $scope.openModifyBloodGlucoseModal = function (bgid, glu, measureTime, timeArea) {
        $scope.modifyBloodGlucoseModal.show();
        $scope.bg.bgid = bgid;
        $scope.bg.modifyGlu = parseInt(glu);
        $scope.bg.measureTime = measureTime;
        $scope.bg.timeArea = timeArea;
    }
    //关闭修改血糖modal
    $scope.closeModifyBloodGlucoseModal = function () {
        $scope.modifyBloodGlucoseModal.hide();
    }
    //修改血糖记录
    $scope.ModifyBloodGlucose = function () {
        if ($scope.bg.modifyGlu == "" || $scope.bg.modifyGlu == null) {
            $fwCordovaToast.showShortBottom("请填写血糖值");
        } else if ($scope.bg.measureTime == "") {
            $fwCordovaToast.showShortBottom("请填写记录时间");
        } else if ($scope.bg.timeArea == "") {
            $fwCordovaToast.showShortBottom("请选择时间段");
        } else {
            HealthService.modifyBloodGlucose($scope.bg.bgid, $scope.bg.modifyGlu, $scope.bg.measureTime, $scope.bg.timeArea).then(function (data) {
                if (data.result == 1) {
                    $scope.modifyBloodGlucoseModal.hide();
                    $scope.loadBloodGlucoseList();

                    $fwCordovaToast.showShortBottom("修改成功");
                } else {
                    $fwCordovaToast.showShortBottom(data.msg);
                }

            });
        }
    }
    //删除血糖记录
    $scope.DeleteBloodGlucose = function () {
        var confirmBpPopup = $ionicPopup.confirm({
            title: '确认删除',
            template: '是否确认删除本条血糖记录',
            cancelText: '取消',
            okText: '删除'
        });

        confirmBpPopup.then(function (res) {
            if (res) {
                HealthService.deleteBloodGlucose($scope.bg.bgid).then(function (data) {
                    if (data.result == 1) {
                        $scope.modifyBloodGlucoseModal.hide();
                        $scope.loadBloodGlucoseList();

                        $fwCordovaToast.showShortBottom("删除成功");
                    } else {
                        $fwCordovaToast.showShortBottom(data.msg);
                    }
                });
            }
            else {

            }
        });
    }
    //长按出菜单删除
    $scope.onHoldBg = function (bgid) {
        var ActionSheetBg = $ionicActionSheet.show({
            destructiveText: '删除',
            cancelText: '取消',
            destructiveButtonClicked: function () {
                ActionSheetBg();

                var confirmBgPopup = $ionicPopup.confirm({
                    title: '确认删除',
                    template: '是否确认删除本条血糖记录',
                    cancelText: '取消',
                    okText: '删除'
                });

                confirmBgPopup.then(function (res) {
                    if (res) {
                        HealthService.deleteBloodGlucose(bgid).then(function (data) {
                            if (data.result == 1) {
                                $scope.loadBloodGlucoseList();

                                $fwCordovaToast.showShortBottom("删除成功");
                            } else {
                                $fwCordovaToast.showShortBottom(data.msg);
                            }
                        });
                    }
                    else {

                    }
                });
            }
        });
    }

    // #endregion

    $scope.tabSwitch = function (tabName) {
        $scope.tabName = tabName;
        if ($scope.titleName == '血压' && tabName == '趋势') {
            chartBloodPressure();
        } else if ($scope.titleName == '心率' && tabName == '趋势') {
            chartHeartRate();
        } else if ($scope.titleName == "身高体重" && tabName == '趋势') {
            chartHeightWeight();
        } else if ($scope.titleName == "血糖" && tabName == '趋势') {
            chartBloodGlucose();
        }

    }

    $scope.switchBloodPressureChart = function () {
        chartBloodPressure();
    }

    //highcharts
    //血压趋势图
    function chartBloodPressure() {
        HealthService.bloodPressureTendency($scope.chartType.bp, $scope.vpId).then(function (data) {
            console.log(data);
            $("#blood-pressure-chart").highcharts({
                credits: {
                    enabled: false
                },
                chart: {
                    type: 'line'
                },
                title: {
                    text: '血压趋势图'
                },
                //subtitle: {
                //    text: '副标题'
                //},
                xAxis: {
                    categories: data[0]
                },
                yAxis: {
                    title: {
                        text: 'mmHg'
                    }
                },
                tooltip: {
                    crosshairs: true,
                    shared: true
                },
                plotOptions: {
                    line: {
                        dataLabels: {
                            enabled: true
                        },
                        enableMouseTracking: true
                    }
                },
                series: [{
                    name: '高压',
                    data: data[1]
                }, {
                    name: '低压',
                    data: data[2]
                }]
            });
        });
    }

    $scope.switchHeartRateChart = function () {
        chartHeartRate();
    }

    //highcharts
    //心率趋势图
    function chartHeartRate() {
        HealthService.heartRateTendency($scope.chartType.hr, $scope.vpId).then(function (data) {
            console.log(data);
            $("#heart-rate-chart").highcharts({
                credits: {
                    enabled: false
                },
                chart: {
                    type: 'line'
                },
                title: {
                    text: '心率趋势图'
                },
                //subtitle: {
                //    text: '副标题'
                //},
                xAxis: {
                    categories: data[0]
                },
                yAxis: {
                    title: {
                        text: '次/分钟'
                    }
                },
                tooltip: {
                    crosshairs: true,
                    shared: true
                },
                plotOptions: {
                    line: {
                        dataLabels: {
                            enabled: true
                        },
                        enableMouseTracking: true
                    }
                },
                series: [{
                    name: '心率',
                    data: data[1]
                }]
            });
        });
    }

    // highcharts
    // BMI趋势图
    function chartHeightWeight() {
        HealthService.heightWeightTendency($scope.chartType.hw, $scope.vpId).then(function (data) {
            console.log(data);
            $("#height-weight-chart").highcharts({
                credits: {
                    enabled: false
                },
                chart: {
                    type: 'line'
                },
                title: {
                    text: '身高体重趋势图'
                },
                //subtitle: {
                //    text: '副标题'
                //},
                xAxis: {
                    categories: data[0]
                },
                //yAxis: {
                //    title: {
                //        text: 'mmHg'
                //    }
                //},
                tooltip: {
                    crosshairs: true,
                    shared: true
                },
                plotOptions: {
                    line: {
                        dataLabels: {
                            enabled: true
                        },
                        enableMouseTracking: true
                    }
                },
                series: [{
                    name: 'BMI',
                    data: data[1]
                }]
            });
        });
    }

    $scope.switchHeightWeightChart = function () {
        chartHeightWeight();
    }

    // highcharts
    // 血糖趋势图
    function chartBloodGlucose() {
        HealthService.bloodGlucoseTendency($scope.chartType.bg, $scope.vpId).then(function (data) {
            console.log(data);
            $("#blood-glucose-chart").highcharts({
                credits: {
                    enabled: false
                },
                chart: {
                    type: 'line'
                },
                title: {
                    text: '血糖趋势图'
                },
                //subtitle: {
                //    text: '副标题'
                //},
                xAxis: {
                    categories: data[0]
                },
                yAxis: {
                    title: {
                        text: 'mmol/L'
                    }
                },
                tooltip: {
                    crosshairs: true,
                    shared: true
                },
                plotOptions: {
                    line: {
                        dataLabels: {
                            enabled: true
                        },
                        enableMouseTracking: true
                    }
                },
                series: [{
                    name: '空腹',
                    data: data[1]
                }, {
                    name: '餐后2小时',
                    data: data[2]
                }]
            });
        });
    }

    $scope.switchBloodGlucoseChart = function () {
        chartBloodGlucose();
    }

    $scope.tile = function (title) {
        $scope.titleName = title;
        $scope.changeVp($scope.vpId);
    }

    $scope.tileHref = function (title) {
        switch (title) {
            case "饮食":
                $state.go("app.diet", { vpid: $scope.vpId });
                break;
            case "吸烟":
                $state.go("app.smoking", { vpid: $scope.vpId });
                break;
        }
    }

    $scope.tileHrefSrvy = function (type) {
        $state.go("app.srvy", { vpid: $scope.vpId, type: type });
    }

    $scope.goCVDRisk = function () {
        $state.go("app.cvdriskList", { vpId: $scope.vpId });
    }

    $scope.goTile = function () {
        // 专病随访进入，直接返回 hzg 20220105
        if ($scope.from == 'flupSrvy') {
            $state.go("app.flupSrvy", { vpId: $scope.vpId });
            return true;
        }

        if ($scope.titleName == "健康记录") {
            if ($scope.from == "menu") {
                //$scope.toggleSlideMenu();
                $rootScope.goBack();
            }
            else if ($scope.from == "app.home") {
                $state.go("app.home");
            }
            else {
                $state.go('app.visitPatient', { vpid: $scope.vpId });
            }
        } else {
            $scope.titleName = "健康记录";
            $scope.getHlthAdvice();
        }
    }

    // 2021-3-12 13:25:19 HM 应4S标准，增加健康指标
    $scope.getHlthAdvice = function () {
        HealthService.getHlthAdvice($scope.vpId).then(function (data) {
            if (data.result == 0) {
                // 2021-4-26 13:34:23 HM 取消掉健康指标报错，这个报错前端给吃下来
                // $fwCordovaToast.showShortBottom(data.msg);
                $scope.hlthAdviceList = [];
            }
            else {
                $scope.hlthAdviceList = data.data;
            }

            $ionicScrollDelegate.resize();
            $ionicScrollDelegate.scrollTop();
        });
    }

    $scope.goAdvice = function (type) {
        switch (type) {
            case "BLOOD_PRESSURE":
                $scope.tile('血压');
                break;
            case "HEART_RATE":
                $scope.tile('心率');
                break;
            case "SPECIAL_EVENT":
                $scope.tile('特殊事件');
                break;
            case "FOOD":
                $scope.tileHref('饮食');
                break;
            case "FAGERSTORM":
                $scope.tileHrefSrvy('FAGERSTORM');
                break;
            case "IPAQ":
                $scope.tileHrefSrvy('IPAQ');
                break;
            case "PSQI":
                $scope.tileHrefSrvy('PSQI');
                break;
            case "SAS":
                $scope.tileHrefSrvy('SAS');
                break;
            case "HEIGHT_WEIGHT":
                $scope.tile('身高体重');
                break;
            case "BLOOD_GLUCOSE":
                $scope.tile('血糖');
                break;
        }
    }

    $scope.judgeAdvice = function (type) {
        // 包含的话，就隐藏，所以这里是false，可以直接用
        for (var i = 0; i < $scope.hlthAdviceList.length; i++) {
            if ($scope.hlthAdviceList[i].HEALTH_TYPE == type) {
                return false;
            }
        }
        return true;
    }

    // 是否提示血压异常
    $scope.getBPNoticeStatus = function () {
        var objBP = $scope.hlthAdviceList.filter(o => o.HEALTH_TYPE == "BLOOD_PRESSURE");
        if (objBP.length > 0 && objBP[0].BP_NOTICE != null) {
            $scope.bpNotice = objBP[0].BP_NOTICE;
            return true;
        }
        return false;
    }

    // 跳转在线问诊
    $scope.goConsultation = function () {
        $state.go('app.dealWithCard', { go: 'consultation' });
    }

    // 跳转预约挂号
    $scope.goOpAppt = function () {
        $state.go('app.opAppt');
    }

    // 跳转健康宣教
    $scope.goEdu = function (columnId) {
        $state.go("app.edu", { columnId: columnId });
    }

    // 跳转健康宣教文章
    $scope.goEduArticle = function (url) {
        $cordovaInAppBrowser.open(url, '_system').then(function (event) { });
    }

    // 2021-12-13 18:13:55 HM 北京市便民惠民评审，做个假的可穿戴，未来可能会梦想成真
    $scope.honor = {};
    $scope.honor.mode = "STEP_RECORD";
    $scope.honor.tabName = "记录";
    $scope.honor.list = [];
    $scope.honor.chartType = {
        bp: "byDay",
        hr: "byDay",
        hw: "byDay",
        bg: "byDay"
    }
    $scope.goHonor = function () {
        // 展示方式
        $scope.honorModeShow();
    }

    // 步数记录
    $scope.stepRecordHonor = function () {
        $scope.honor.mode = "STEP_RECORD";
        $scope.honor.tabName = "记录";
        $scope.honor.list = [];
        $scope.honor.chartType = {
            bp: "byDay",
            hr: "byDay",
            hw: "byDay",
            bg: "byDay"
        }

        $ionicLoading.show();
        HealthService.getStepRecordHonorList($scope.vpId, "STEP_RECORD").then(function (data) {
            $ionicLoading.hide();
            if (data.result == 0) {
                $ionicPopup.alert({
                    title: '提示',
                    template: data.msg,
                    okText: "确定"
                });
            }
            else {
                // 变量赋值
                $scope.honor.mode = "STEP_RECORD";
                $scope.honor.list = data.ds;

                $scope.honorRecordShow();
            }
        }, function (data) {
            $ionicLoading.hide();
            $ionicPopup.alert({
                title: '提示',
                template: "网络不佳，请稍后重试",
                okText: "确定"
            });
        })
    }

    // 心脏健康
    $scope.heartRecordHonor = function () {
        $scope.honor.mode = "STEP_RECORD";
        $scope.honor.tabName = "记录";
        $scope.honor.list = [];
        $scope.honor.chartType = {
            bp: "byDay",
            hr: "byDay",
            hw: "byDay",
            bg: "byDay"
        }

        $ionicLoading.show();
        HealthService.getStepRecordHonorList($scope.vpId, "HEART_WEAR").then(function (data) {
            $ionicLoading.hide();
            if (data.result == 0) {
                $ionicPopup.alert({
                    title: '提示',
                    template: data.msg,
                    okText: "确定"
                });
            }
            else {
                // 变量赋值
                $scope.honor.mode = "HEART_WEAR";
                $scope.honor.list = data.ds;

                $scope.honorRecordShow();
            }
        }, function (data) {
            $ionicLoading.hide();
            $ionicPopup.alert({
                title: '提示',
                template: "网络不佳，请稍后重试",
                okText: "确定"
            });
        })
    }

    // 荣耀切换
    $scope.honorTabSwitch = function (tabName) {
        $scope.honor.tabName = tabName;
        if ($scope.honor.mode == "HEART_WEAR" && tabName == '趋势') {
            honorChartHeartRate();
        }
        else if ($scope.honor.mode == "STEP_RECORD" && tabName == '趋势') {
            honorChartStepRecord();
        }
    }

    $scope.honorSwitch = function () {
        if ($scope.honor.mode == "HEART_WEAR") {
            honorChartHeartRate();
        }
        else if ($scope.honor.mode == "STEP_RECORD") {
            honorChartStepRecord();
        }
    }

    function honorChartHeartRate() {
        HealthService.heartRateTendencyHonor($scope.honor.chartType.hr, $scope.vpId).then(function (data) {
            console.log(data);
            console.log($("#heart-rate-chart-honor"));
            $("#heart-rate-chart-honor").highcharts({
                credits: {
                    enabled: false
                },
                chart: {
                    type: 'line'
                },
                title: {
                    text: '静息心率趋势图'
                },
                //subtitle: {
                //    text: '副标题'
                //},
                xAxis: {
                    categories: data[0]
                },
                yAxis: {
                    title: {
                        text: '次/分钟'
                    }
                },
                tooltip: {
                    crosshairs: true,
                    shared: true
                },
                plotOptions: {
                    line: {
                        dataLabels: {
                            enabled: true
                        },
                        enableMouseTracking: true
                    }
                },
                series: [{
                    name: '心率',
                    data: data[1]
                }]
            });
        });
    }

    function honorChartStepRecord() {
        HealthService.stepRecordTendencyHonor($scope.honor.chartType.hr, $scope.vpId).then(function (data) {
            console.log(data);
            console.log($("#heart-rate-chart-honor"));
            $("#heart-rate-chart-honor").highcharts({
                credits: {
                    enabled: false
                },
                chart: {
                    type: 'line'
                },
                title: {
                    text: '步数趋势图'
                },
                //subtitle: {
                //    text: '副标题'
                //},
                xAxis: {
                    categories: data[0]
                },
                yAxis: {
                    title: {
                        text: '步'
                    }
                },
                tooltip: {
                    crosshairs: true,
                    shared: true
                },
                plotOptions: {
                    line: {
                        dataLabels: {
                            enabled: true
                        },
                        enableMouseTracking: true
                    }
                },
                series: [{
                    name: '步数',
                    data: data[1]
                }]
            });
        });
    }

    $ionicModal.fromTemplateUrl('honorMode.html', {
        scope: $scope
    }).then(function (modal) {
        $scope.honorModeModal = modal;
    });

    $ionicModal.fromTemplateUrl('honorRecord.html', {
        scope: $scope
    }).then(function (modal) {
        $scope.honorRecordModal = modal;
    });

    // 销毁模态窗口
    $scope.$on('$destroy', function () {
        $scope.honorModeModal.remove();
        $scope.honorRecordModal.remove();
    })

    // 荣耀手环方式显示
    $scope.honorModeShow = function () {
        $scope.honorModeModal.show();
    }

    // 荣耀手环方式隐藏
    $scope.honorModeHide = function () {
        $scope.honorModeModal.hide();
    }

    // 荣耀手环记录显示
    $scope.honorRecordShow = function () {
        $scope.honorRecordModal.show();
    }

    // 荣耀手环记录隐藏
    $scope.honorRecordHide = function () {
        $scope.honorRecordModal.hide();
    }

    // 页面进入，绑定后退事件
    $scope.$on('$ionicView.enter', function () {
        $ionicPlatform.registerBackButtonAction(function (e) {
            if ($scope.titleName == "健康记录") {
                //alert('2');
                //$state.go("app.home");
                if ($stateParams.vpid == "") {
                    $state.go("app.home");
                    //$rootScope.goBack();
                }
                else {
                    //$scope.toggleSlideMenu();
                    $state.go('app.visitPatient', { vpid: $scope.vpId });
                }
            } else {
                //alert('1');
                $scope.titleName = "健康记录";
                $state.go("app.health");
            }
            e.preventDefault();
            return false;
        }, 135, 'health');

        // 获取配置
        HealthService.getConfig().then(function (data) {
            // 查询成功
            if (data.result == 1) {
                // 2021-4-27 20:03:04 候诊叫号显示等候人数及等待时间
                if (devMode || data.data.cvdRiskServerStatus) {
                    $scope.cvdRiskServerStatus = true;
                }
            }
        })
    });

    // 页面退出，解除后退绑定
    // 可能绑定的事件得改
    $scope.$on('$ionicView.beforeLeave', function () {
        //        setTimeout(function () {
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'health') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
        //        }, 500);
    });

    //#region cordova日期选择
    $scope.datePicker = function (target, type, value) {
        console.log(target);
        var defaultDate = new Date();

        if (value != undefined && value != null && value != '') {
            // 处理iOS日期格式
            if (currentPlatform == "iOS") {
                value = value.replace(/-/g, "/");
            }
            defaultDate = new Date(value);
        }
        var options = {
            mode: type,  	// 'date' or 'time' or 'datetime'
            date: defaultDate,
            okText: '确定',
            cancelText: '取消',
            doneButtonLabel: '确定',
            cancelButtonLabel: '取消',
            is24Hour: true,
            androidTheme: 3,
            locale: 'zh_cn'
        };

        $cordovaDatePicker.show(options).then(function (date) {
            if (typeof (date) != 'undefined') {
                var resultDate = new Date(date)
                switch (target) {
                    case 'bp.measureTime':    // 血压记录时间
                        $scope.bp.measureTime = resultDate.Format('yyyy-MM-dd hh:mm:ss');
                        break;
                    case 'hr.measureTime':      // 心率记录时间
                        $scope.hr.measureTime = resultDate.Format('yyyy-MM-dd hh:mm:ss');
                        break;
                    case 'se.appearedTime':       // 特殊事件症状出现时间
                        $scope.se.appearedTime = resultDate.Format('yyyy-MM-dd hh:mm:ss');
                        break;
                    case 'hw.measureTime':      // 身高体重时间
                        $scope.hw.measureTime = resultDate.Format('yyyy-MM-dd hh:mm:ss');
                        break;
                    case 'bg.measureTime':      // 血糖时间
                        $scope.bg.measureTime = resultDate.Format('yyyy-MM-dd hh:mm:ss');
                        break;
                    case 'edit_logtime':        // TBA
                        $scope.currentSolve.logtime = resultDate.Format('yyyy-MM-dd hh:mm:ss');
                        break;
                }
            }
        });
    }
    //#endregion
})
