﻿angular.module('fwapp.services')

// 住院登记
.service('IpRegService', function ($q, $http, $timeout, BaseService) {
    return {
        // 获取用户须知数据
        agreement: function () {
            return BaseService.post("/IpReg/Agreement");
        },
        // 检查拟入院日期、床位类型服务状态
        checkDateBedServerStatus: function () {
            return BaseService.post("/IpReg/CheckDateBedServerStatus");
        },
        // 获取字典
        getDict: function (type, pcode) {
            return BaseService.post("/IpReg/GetDict", { type: type, pcode: pcode });
        },
        // 获取绑卡帮助
        getBindCardHelp: function () {
            return BaseService.post("/IpReg/GetBindCardHelp");
        },
        // 添加预约信息
        addIPNoticeExpectedDate: function (date,bed,name,num,inid) {
            return BaseService.post("/IpReg/AddIPNoticeExpectedDate", { EXPECTED_IP_DATE : date, EXPECTED_BED_TYPE : bed,
             VISIT_PATIENT_NAME : name, HIS_CARD_NUM : num, HIS_IP_NOTICE_ID : inid});
        },
        // 查询预约信息
        getIPNoticeExpectedDate: function (num,inid) {
            return BaseService.post("/IpReg/GetIPNoticeExpectedDate", { HIS_CARD_NUM : num, HIS_IP_NOTICE_ID : inid});
        },
        // 获取住院单状态
        checkIPNotice: function (vpId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/CheckIPNotice",
                data: { visitPatientId: vpId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else if (data.result == -1) {
                    deferred.resolve(data);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取当前用户住院单
        getIPNotice: function () {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/GetIPNotice",
                data: { 1: 1 },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else if (data.result == -1) {
                    deferred.resolve(data);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 验证住院登记信息V2
        checkIpRegV2: function (hisCardNum, ipNoticeId) {
            return BaseService.post("/IpReg/CheckIpRegV2", { hisCardNum: hisCardNum, ipNoticeId: ipNoticeId });
        },
        // 获取当前用户住院单
        getIPNoticeV2: function (hisCardNum, ipNoticeId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/GetIPNoticeV2",
                data: { hisCardNum: hisCardNum, ipNoticeId: ipNoticeId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else if (data.result == -1) {
                    deferred.resolve(data);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取最近一次住院登记信息
        getLastIPRegInfo: function (vpId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/GetLastIPRegInfo",
                data: { visitPatientId: vpId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else if (data.result == -1) {
                    deferred.resolve(data);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取最近一次住院登记信息V2
        getLastIPRegInfoV2: function (vpId, hisCardNum, ipNoticeId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/GetLastIPRegInfoV2",
                data: { visitPatientId: vpId, hisCardNum: hisCardNum, ipNoticeId: ipNoticeId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else if (data.result == -1) {
                    deferred.resolve(data);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取住院登记信息
        getIpReg: function (vpid) {
            return BaseService.post("/IpReg/GetIpReg", { vpid: vpid });
        },
        // 获取住院登记信息V2
        getIpRegV2: function (hisCardNum, ipNoticeId, patientName) {
            return BaseService.post("/IpReg/GetIpRegV2", { hisCardNum: hisCardNum, ipNoticeId: ipNoticeId, patientName: jsencrypt.encrypt(patientName) });
        },
        // 保存住院登记信息
        saveIpReg: function (ipRegInfo, vpid, hisCardNum, ipNoticeId, from, isBaby, age) {
            // 2019-5-31 11:16:12 jsencrypt.js 加密
            // 深度复制
            var data = {};
            $.extend(data, ipRegInfo);
            if (data) {
                var keyList = ["BIRTH_HOSPITAL", "NEWBORN_WEIGHT", "WORK_ADDRESS", "WORK_TEL", "WORK_POSTCODE", "HOUSEHOLD_DETAIL", "HOUSEHOLD_POSTCODE", "ADDRESS_DETAIL", "ADDRESS_POSTCODE", "TEL", "EMAIL", "CONTACT_NAME", "CONTACT_TEL", "CONTACT_ADDRESS"]
                Object.keys(data).forEach(e => {
                    if (keyList.indexOf(e) >= 0 && data[e] != null && data[e] != "") {
                        data[e] = jsencrypt.encrypt(data[e]);
                    }
                })
            }
            data.vpid = vpid;
            data.hisCardNum = hisCardNum;
            data.ipNoticeId = ipNoticeId;
            data.from = from;
            data.isBaby = isBaby;
            data.age = age;
            return BaseService.post("/IpReg/SaveIpReg", data);
        }
    }

    // 异步等待通用方法
    function WaitResponse(deferred, requestId, count) {
        var timer = $timeout(function () {
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetResponse',
                data: { requestId: requestId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    deferred.resolve(data);
                }
                else {
                    if (count <= 10) {
                        WaitResponse(deferred, requestId, count + 1);
                    }
                    else {
                        deferred.resolve({ result: 99 });
                    }
                }
            })
        }, 1100);
    }
})