﻿angular.module('fwapp.services')

.service('RequestService', function ($q, $http, $timeout, BaseService) {
    return {
        // 检查就诊卡
        checkPatientCard: function (visitPatientId, cardNum, phoneNum) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckPatientCard',
                data: { visitPatientId: visitPatientId, cardNum: cardNum, phoneNum: phoneNum },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取电话
        GetReservedPhone: function (visitPatientId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetReservedPhone',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取LIS检验项目列表
        lisList: function (visitPatientId, type, queryToken) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/LisList',
                data: { visitPatientId: visitPatientId, type: type, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取LIS检验项目结果
        lisResult: function (visitPatientId, sampleNo, queryToken) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/LisResult',
                data: { visitPatientId: visitPatientId, sampleNo: sampleNo, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        //下载PDF
        downloadPDF: function (reqId, vpID) {
            var deferred = $q.defer();
            // 异步等待 检查PDF是否存在
            function WaitResponsePDF(deferred, reqId, count, vpID) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/CheckResponsePDF',
                        data: { requestId: reqId, vpID: vpID },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1 && data.is_null == 0) {
                            console.log(data);
                            deferred.resolve(data);
                        } else {
                            if (count <= 20) {
                                WaitResponsePDF(deferred, reqId, count + 1, vpID);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    }).error(function (data, status) {
                        deferred.reject(data);
                    });
                }, 1100);
            }
            WaitResponsePDF(deferred, reqId, 0, vpID);
            return deferred.promise;
        },
        // 获取检查报告图片
        checkResult: function (visitPatientId, accnoId, checkType, queryToken) {
            var deferred = $q.defer();
            // 异步等待 获取检查报告图片
            function WaitResponseImage(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseImage',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImage(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckResult',
                data: { visitPatientId: visitPatientId, accnoId: accnoId, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                // 轮询获取图片 新请求
                if (data.result == 1) {
                    WaitResponseImage(deferred, data.data, 0);
                }
                // 轮询获取图片 缓存
                else if (data.result == -1 && data.is_null == 0 && data.data != null && data.data.length > 0) {
                    WaitResponseImage(deferred, data.data[0].REQUEST_ID, 0);
                }
                // 查询密码错误
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查报告图片 --- 自助机接口
        unClearResult: function (visitPatientId, sqdbh, queryToken, printType) {
            var deferred = $q.defer();
            // 异步等待 获取检查报告图片
            function WaitResponseImage(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseImage',
                        data: { requestId: requestId, columnName: "APPL_DATA" },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImage(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/UnclearResult',
                data: { visitPatientId: visitPatientId, sqdbh: sqdbh, queryToken: queryToken, printType: printType },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                // 轮询获取图片 新请求
                if (data.result == 1) {
                    WaitResponseImage(deferred, data.data, 0);
                }
                // 轮询获取图片 缓存
                else if (data.result == -1 && data.is_null == 0 && data.data != null && data.data.length > 0) {
                    WaitResponseImage(deferred, data.data[0].REQUEST_ID, 0);
                }
                // 查询密码错误
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取候诊叫号信息
        opCallList: function () {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/OpCallList',
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查列表
        checkList: function (visitPatientId, type, queryToken) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckList',
                data: { visitPatientId: visitPatientId, type: type, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取核医学科检查列表 --- 自助机接口
        unClearList: function (visitPatientId, type, queryToken, printType) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/UnClearList',
                data: { visitPatientId: visitPatientId, type: type, queryToken: queryToken, printType: printType },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 查询手术状态
        surgicalState: function () {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/SurgicalState',
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 院外病历浏览授权
        outRecordAuth: function (visitPatientId, auth) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/OutRecordAuth',
                data: { visitPatientId: visitPatientId, auth: auth },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取外院诊疗医院列表
        getOutRecordHosp: function (visitPatientId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetOutRecordHosp',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 同步院外病历医院授权状态
        syncOutRecordHospAuth: function (visitPatientId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/SyncOutRecordHospAuth',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查预约列表
        checkApptList: function () {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckApptList',
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查预约列表
        getCheckItemSched: function (hisCardNum, checkApptId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetCheckItemSched',
                data: { hisCardNum: hisCardNum, checkApptId: checkApptId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 检查预约改期提交
        // 2019-12-2 08:23:40 HM 支持缴费前检查预约
        checkApptUpdate: function (hisCardNum, checkApptId, orderDate, timeAreaId, checkListNum) {

            // 2019-12-2 08:23:40 HM 支持缴费前检查预约
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckApptUpdate',
                data: { hisCardNum: hisCardNum, checkApptId: checkApptId, orderDate: orderDate, timeAreaId: timeAreaId, checkListNum: checkListNum },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取门诊处方
        getOpPrescription: function (visitPatientId, queryToken) {
            var deferred = $q.defer();
            function RespOpPrescription(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/RespOpPrescription',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                RespOpPrescription(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetOpPrescription',
                data: { visitPatientId: visitPatientId, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    RespOpPrescription(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取门诊药品
        getOpDrug: function (visitPatientId, queryToken) {
            var deferred = $q.defer();
            // 异步等待通用方法
            function RespOPDrug(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/RespOPDrug',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                RespOPDrug(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetOpDrug',
                data: { visitPatientId: visitPatientId, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 && data.is_null == 0 && data.data != null && data.data.length > 0) {
                    RespOPDrug(deferred, data.data[0].REQUEST_ID, 0);
                }
                else if (data.result == -1 || data.result == 0) {    // 若返回缓存结果为空 || 报错
                    deferred.resolve(data);
                }
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    RespOPDrug(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取住院结算审核信息
        getIPDischargeAudit: function (data) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                data: data,
                url: serviceUrl + '/Request/GetIPDischargeAudit',
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                } else {
                    deferred.resolve(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查叫号信息
        getCheckCalllist: function () {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetCheckCalllist',
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                } else {
                    deferred.resolve(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查申请单列表
        checkApplList: function () {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckApplList',
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查申请单图片
        checkApplImage: function (hisCardNum, checkApplId) {
            var deferred = $q.defer();
            // 异步等待 获取检查申请单图片
            function WaitResponseImage(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseImage',
                        data: { requestId: requestId, columnName: 'APPL_DATA' },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImage(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetCheckApplImg',
                data: { hisCardNum: hisCardNum, checkApplId: checkApplId },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                // 轮询获取图片 新请求
                if (data.result == 1) {
                    WaitResponseImage(deferred, data.data, 0);
                }
                // 轮询获取图片 缓存
                else if (data.result == -1 && data.is_null == 0 && data.data != null && data.data.length > 0) {
                    WaitResponseImage(deferred, data.data[0].REQUEST_ID, 0);
                }
                // 查询密码错误
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 住院满意度：住院号及姓名 =>换 患者信息 =>后台保存 住院满意度表
        ipSatisCheckPatient: function (inpatientId, name) {
            var deferred = $q.defer();
            function WaitResponseIpSatis(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/WaitResponseIpSatis',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        // 成功、且存成功
                        if (data.result == 1) {
                            deferred.resolve({ result: 1, satisId: data.satisId });
                        }
                        // 成功、但存失败
                        else if (data.result == 0) {
                            deferred.resolve({ result: 0, msg: data.msg });
                        }
                        // 未查到就诊人
                        else if (data.result == 50002) {
                            deferred.resolve({ result: 0, msg: "未能查到就诊人，请核实病案号及患者姓名" });
                        }
                        // 并发(应该仅缓存rid出现...所以是count+1还是是0..)
                        else if (data.result == 50003) {
                            console.log("!");
                            WaitResponseIpSatis(deferred, requestId, count + 1);
                        }
                        // 根本没查到
                        else {
                            // 再试一次
                            if (count <= 10) {
                                WaitResponseIpSatis(deferred, requestId, count + 1);
                            }
                            // 算了吧
                            else {
                                deferred.resolve({ result: 0, msg: "网络原因，请稍后重试" });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/IpSatisCheckPatient',
                data: { inpatientId: inpatientId, name: name },
                withCredentials: true
            }).success(function (data, status) {
                // 报错
                if (data.result == 0) {
                    deferred.resolve(data);
                }
                // 缓存 || 成功
                else {
                    WaitResponseIpSatis(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取住院患者信息
        getIPPatientInfo: function (visitPatientId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetIPPatientInfo',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取住院预存充值明细
        getIPChargeList: function (visitPatientId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetIPChargeList',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 病案复印：patient_name/id_code =>换 患者信息 =>后台对比out_date =>妥 保存病案复印表
        casePrintCheckPatient: function (patient_name, id_code, out_date) {
            var deferred = $q.defer();
            function WaitResponseCasePrint(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/WaitResponseCasePrint',
                        data: { requestId: requestId, out_date: out_date },
                        withCredentials: true
                    }).success(function (data, status) {
                        // 成功
                        if (data.result == 1) {
                            deferred.resolve({ result: 1, applyId: data.applyId });
                        }
                        // 存表过程中，出现错误
                        else if (data.result == 0) {
                            deferred.resolve({ result: 0, msg: data.msg });
                        }
                        // 未查到就诊人
                        else if (data.result == 50002) {
                            deferred.resolve({ result: 0, msg: "未查到此就诊人，请核查所填姓名/身份证号" });
                        }
                        // 根本没查到
                        else {
                            // 再试一次
                            if (count <= 10) {
                                WaitResponseCasePrint(deferred, requestId, count + 1);
                            }
                            // 算了吧
                            else {
                                deferred.resolve({ result: 0, msg: "网络原因，请稍后重试" });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CasePrintCheckPatient',
                data: { patient_name: patient_name, id_code: id_code },
                withCredentials: true
            }).success(function (data, status) {
                // 报错
                if (data.result == 0) {
                    deferred.resolve(data);
                }
                // 缓存 || 成功
                else {
                    WaitResponseCasePrint(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取可预约时间
        preCheckAppt: function (vpId, checkListNum) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/PreCheckAppt',
                data: { vpId: vpId, checkListNum: checkListNum },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 消息流号序
        MessageStreamNumberSenquence: function (requestId) {
            var deferred = $q.defer();
            WaitResponse(deferred, requestId, 0);
            return deferred.promise;
        },
        // 等候人数(不要了)
        opWaitCount: function (vpId, bloodType, myIndex) {
            var deferred = $q.defer();
            function WaitResponseWaitCount(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/WaitResponseWaitCount',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        // 成功
                        if (data.result == 1) {
                            deferred.resolve({ result: 1, wait_count: data.wait_count, wait_time: data.wait_time });
                        }
                        // 未查到就诊人 =>显示原等待人数
                        else if (data.result == 50002) {
                            deferred.resolve({ result: 0, msg: "未查到就诊人" });
                        }
                        // 根本没查到
                        else {
                            // 再试试
                            if (count < 5) {
                                WaitResponseWaitCount(deferred, requestId, count + 1);
                            }
                            // 算了吧
                            else {
                                deferred.resolve({ result: 0, msg: "根本没查到" });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/OpWaitCount',
                data: { vpId: vpId, bloodType: bloodType, myIndex: myIndex },
                withCredentials: true
            }).success(function (data, status) {
                // 报错
                if (data.result == 0) {
                    deferred.resolve(data);
                }
                // 缓存 || 成功
                else {
                    WaitResponseWaitCount(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 医保患者
        checkMI: function (vpid) {
            var deferred = $q.defer();
            function WaitResponseCheckMI(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/WaitResponseCheckMI',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        // 成功
                        if (data.result == 1) {
                            deferred.resolve({ result: 1, descr: data.descr, help: data.help, isMI: data.isMI, requestId: requestId });
                        }
                        // 未查到就诊人
                        else if (data.result == 50002) {
                            deferred.resolve({ result: 0, msg: "未查到就诊人的医保信息" });
                        }
                        // 根本没查到
                        else {
                            // 再试一次
                            if (count < 20) {
                                WaitResponseCheckMI(deferred, requestId, count + 1);
                            }
                            // 算了吧
                            else {
                                deferred.resolve({ result: 0, msg: "网络原因，请稍后重试" });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckMI',
                data: { vpid: vpid },
                withCredentials: true
            }).success(function (data, status) {
                // 报错
                if (data.result == 0) {
                    deferred.resolve(data);
                }
                // 缓存 || 成功
                else {
                    WaitResponseCheckMI(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 医保金额拆分
        miPreDivideRevisit: function (vpId, doctorCode) {
            var deferred = $q.defer();
            function WaitResponseMIPre(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponse',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 10) {
                                WaitResponse(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/MIPreDivideRevisit',
                data: { vpId: vpId, doctorCode: doctorCode },
                withCredentials: true
            }).success(function (data, status) {
                // 报错
                if (data.result == 0) {
                    deferred.resolve(data);
                }
                // 缓存 || 成功
                else {
                    WaitResponseMIPre(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 修改预留手机号
        changeReservedPhone: function (requestId, vpId, oldPhone, newPhone, vericodeOld, vericodeNew) {
            var deferred = $q.defer();
            function WaitResponseReservedPhone(deferred, logId, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/RespReservedPhone',
                        data: { logId: logId, requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 10) {
                                WaitResponseReservedPhone(deferred, logId, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/ChangeReservedPhone',
                data: { requestId: requestId, vpId: vpId, oldPhone: oldPhone, newPhone: newPhone, vericodeOld: jsencrypt.encrypt(vericodeOld), vericodeNew: jsencrypt.encrypt(vericodeNew) },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponseReservedPhone(deferred, data.data.logId, data.data.requestId, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取门诊病历列表
        opRecordList: function (visitPatientId, type, queryToken) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/OpRecordList',
                data: { visitPatientId: visitPatientId, type: type, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取住院列表
        ipList: function (visitPatientId, type, queryToken) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/IpList',
                data: { visitPatientId: visitPatientId, type: type, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取住院病历
        ipRecordList: function (vpId, idb, type, queryToken) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/IpRecordList',
                data: {
                    vpId: vpId,
                    idb: idb,
                    type: type,
                    queryToken: queryToken
                },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取住院病历详情
        ipRecordDetail: function (vpId, idr, idb, type, oldnew, queryToken) {
            var deferred = $q.defer();

            // 异步等待 获取病历图片
            function WaitResponseImage(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseImage',
                        data: { 
                            requestId: requestId,
                            columnName: "RECORD_DATA"
                        },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImage(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/IpRecordDetail',
                data: {
                    vpId: vpId,
                    idr: idr,
                    idb: idb,
                    type: type,
                    oldnew: oldnew,
                    queryToken: queryToken
                },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponseImage(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取门诊病历详情
        opRecordDetail: function (vpId, idb, idr, lb, kh, zyh, idt, filePath, queryToken) {
            var deferred = $q.defer();

            // 异步等待 获取病历图片
            function WaitResponseImage(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseImage',
                        data: {
                            requestId: requestId,
                            columnName: "RECORD_DATA"
                        },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImage(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/OpRecordDetail',
                data: {
                    vpId: vpId,
                    idb: idb,
                    idr: idr,
                    lb: lb,
                    kh: kh,
                    zyh: zyh,
                    idt: idt,
                    filePath: filePath,
                    queryToken: queryToken
                },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponseImage(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查影像
        checkResultImg: function (visitPatientId, accnoId, queryToken) {
            var deferred = $q.defer();
            // 异步等待 获取检查报告图片
            function WaitResponseImage(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseImage',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImage(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckResultImg',
                data: { visitPatientId: visitPatientId, accnoId: accnoId, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                // 轮询获取图片 新请求
                if (data.result == 1) {
                    WaitResponseImage(deferred, data.data, 0);
                }
                // 轮询获取图片 缓存
                else if (data.result == -1 && data.is_null == 0 && data.data != null && data.data.length > 0) {
                    WaitResponseImage(deferred, data.data[0].REQUEST_ID, 0);
                }
                // 查询密码错误
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 康复候诊叫号
        getRHBCallList: function () {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetRHBCallList',
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                } else {
                    deferred.resolve(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        //获取康复计划
        getRHBPlan: function (visitPatientId) {
            var deferred = $q.defer();
            function WaitResponseRHB(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseRHB',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseRHB(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetRHBPlan',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else {
                    WaitResponseRHB(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取核医学检查报告或门诊病历
        getNuClearList: function (visitPatientId, sqdbh, printType, queryToken) {
            var deferred = $q.defer();
            // 异步等待 获取检查报告图片
            function WaitResponseImage(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseImage',
                        data: { requestId: requestId, columnName: "REPORT_DATA" },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImage(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/UnclearList',
                data: { visitPatientId: visitPatientId, sqdbh: sqdbh, queryToken: queryToken, printType: printType },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                // 轮询获取图片 新请求
                if (data.result == 1) {
                    WaitResponseImage(deferred, data.data, 0);
                }
                // 轮询获取图片 缓存
                else if (data.result == -1 && data.is_null == 0 && data.data != null && data.data.length > 0) {
                    WaitResponseImage(deferred, data.data[0].REQUEST_ID, 0);
                }
                // 查询密码错误
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取门诊处方PDF
        getDrugRecord: function (visitPatientId, recipeNum) {
            var deferred = $q.defer();
            function WaitResponseDrugRecord(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponse',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        // 单独把requestId吐出来，后续需要这个requestID，下载PDF
                        data.requestId = requestId;
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 10) {
                                WaitResponseDrugRecord(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetDrugRecord',
                data: { visitPatientId: visitPatientId, recipeNum: recipeNum },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                // 轮询成功
                if (data.result == 1) {
                    WaitResponseDrugRecord(deferred, data.data, 0);
                }
                else {
                    deferred.resolve(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 美康合理用药
        getRationalMadication: function (visitPatientId, recipeNum) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetRationalMadication',
                data: { visitPatientId: visitPatientId, recipeNum: recipeNum },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                } else {
                    deferred.resolve(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        }
    }

    // 异步等待通用方法
    function WaitResponse(deferred, requestId, count) {
        var timer = $timeout(function () {
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetResponse',
                data: { requestId: requestId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    deferred.resolve(data);
                }
                else {
                    if (count <= 10) {
                        WaitResponse(deferred, requestId, count + 1);
                    }
                    else {
                        deferred.resolve({ result: 99 });
                    }
                }
            })
        }, 1100);
    }
})